OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Password errata",
    "The new password can not be the same as the previous one" : "La nuova password non può essere uguale alla precedente",
    "No user supplied" : "Non è stato fornito alcun utente",
    "Authentication error" : "Errore di autenticazione",
    "Wrong admin recovery password. Please check the password and try again." : "Password amministrativa di ripristino errata. Controlla la password e prova ancora.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Il motore non supporta la modifica della password, ma la chiave di cifratura dell'utente è stata aggiornata correttamente.",
    "Unable to change password" : "Impossibile cambiare la password",
    "%s password changed successfully" : "Password di %s modificata correttamente",
    "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "installazione e aggiornamento delle applicazioni tramite il negozio delle applicazioni o condivisione cloud federata",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utilizza una versione %s datata (%s). Aggiorna il tuo sistema operativo o funzionalità come %s non funzioneranno correttamente.",
    "A problem occurred, please check your log files (Error: %s)" : "Si è verificato un problema, controlla i tuoi file di log (Errore: %s)",
    "Migration Completed" : "Migrazione completata",
    "Group already exists." : "Il gruppo esiste già.",
    "Unable to add group." : "Impossibile aggiungere il gruppo.",
    "Unable to delete group." : "Impossibile eliminare il gruppo.",
    "log-level out of allowed range" : "livello di log fuori dall'intervallo consentito",
    "Saved" : "Salvato",
    "test email settings" : "prova impostazioni email",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Si è verificato un problema durante l'invio dell'email. Controlla le tue impostazioni. (Errore: %s)",
    "Email sent" : "Email inviata",
    "You need to set your user email before being able to send test emails." : "Devi impostare l'indirizzo del tuo utente prima di poter provare l'invio delle email.",
    "Invalid mail address" : "Indirizzo email non valido",
    "A user with that name already exists." : "Un utente con quel nome esiste già.",
    "Unable to create user." : "Impossibile creare l'utente.",
    "Your %s account was created" : "Il tuo account %s è stato creato",
    "Unable to delete user." : "Impossibile eliminare l'utente.",
    "Forbidden" : "Vietato",
    "Invalid user" : "Utente non valido",
    "Unable to change mail address" : "Impossibile cambiare l'indirizzo di posta",
    "Your full name has been changed." : "Il tuo nome completo è stato cambiato.",
    "Unable to change full name" : "Impossibile cambiare il nome completo",
    "Unable to enable/disable user." : "Impossibile abilitare/disabilitare l'utente.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Italiano",
    "Language changed" : "Lingua modificata",
    "Invalid request" : "Richiesta non valida",
    "Admins can't remove themself from the admin group" : "Gli amministratori non possono rimuovere se stessi dal gruppo di amministrazione",
    "Unknown user" : "Utente sconosciuto",
    "Couldn't remove app." : "Impossibile rimuovere l'applicazione.",
    "Official" : "Ufficiale",
    "Approved" : "Approvata",
    "All" : "Tutti",
    "Enabled" : "Abilitata",
    "Not enabled" : "Non abilitata",
    "No apps found for your version" : "Nessuna applicazione trovata per la tua versione",
    "The app will be downloaded from the app store" : "L'applicazione sarà scaricata dallo store delle applicazioni",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Le applicazioni ufficiali sono sviluppate da e con la comunità di ownCloud. Offrono le funzioni fondamentali di ownCloud e sono pronte per l'utilizzo in produzione.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Le applicazioni approvate sono sviluppate da sviluppatori affidabili e hanno passato un rapido controllo di sicurezza. Sono attivamente mantenute in un deposito aperto del codice e i loro responsabili le ritengono pronte sia per un utilizzo casuale che per un utilizzo continuativo.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Questa applicazione non è stata sottoposta a controlli di sicurezza, è nuova o notoriamente instabile. Installala a tuo rischio.",
    "Please wait...." : "Attendere...",
    "Error while disabling app" : "Errore durante la disattivazione",
    "Disable" : "Disabilita",
    "Enable" : "Abilita",
    "Error while enabling app" : "Errore durante l'attivazione",
    "Error: this app cannot be enabled because it makes the server unstable" : "Errore: questa applicazione non può essere abilitata perché rende il server instabile",
    "Error: could not disable broken app" : "Errore: impossibile disabilitare l'applicazione danneggiata",
    "Error while disabling broken app" : "Errore durante la disabilitazione dell'applicazione danneggiata",
    "Updating...." : "Aggiornamento in corso...",
    "Error while updating app" : "Errore durante l'aggiornamento",
    "Updated" : "Aggiornato",
    "Uninstalling ...." : "Disinstallazione...",
    "Error while uninstalling app" : "Errore durante la disinstallazione dell'applicazione",
    "Uninstall" : "Disinstalla",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'applicazione è stata abilitata, ma deve essere aggiornata. Sarai rediretto alla pagina di aggiornamento in 5 secondi.",
    "App update" : "Aggiornamento applicazione",
    "Experimental" : "Sperimentale",
    "No apps found for {query}" : "Nessuna applicazione trovata per {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sei sicuro di voler aggiungere \"{domain}\"  come dominio attendibile?",
    "Add trusted domain" : "Aggiungi dominio attendibile",
    "Migration in progress. Please wait until the migration is finished" : "Migrazione in corso. Attendi fino al completamento della migrazione",
    "Migration started …" : "Migrazione avviata...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Si è verificato un errore. Carica un certificato PEM codificato in ASCII.",
    "Valid until {date}" : "Valido fino al {date}",
    "Delete" : "Elimina",
    "Disconnect" : "Disconnetti",
    "Error while loading browser sessions and device tokens" : "Errore durante il caricamento delle sessioni del browser e dei token di dispositivo",
    "Error while creating device token" : "Errore durante la creazione del token di dispositivo",
    "Error while deleting the token" : "Errore durante l'eliminazione del token",
    "Sending..." : "Invio in corso...",
    "An error occurred: {message}" : "Si è verificato un errore: {message}",
    "Select a profile picture" : "Seleziona un'immagine del profilo",
    "Very weak password" : "Password molto debole",
    "Weak password" : "Password debole",
    "So-so password" : "Password così-così",
    "Good password" : "Password buona",
    "Strong password" : "Password forte",
    "Groups" : "Gruppi",
    "Unable to delete {objName}" : "Impossibile eliminare {objName}",
    "Error creating group: {message}" : "Errore durante la creazione del gruppo: {message}",
    "A valid group name must be provided" : "Deve essere fornito un nome valido per il gruppo",
    "deleted {groupName}" : "{groupName} eliminato",
    "undo" : "annulla",
    "never" : "mai",
    "deleted {userName}" : "{userName} eliminato",
    "add group" : "aggiungi gruppo",
    "Invalid quota value \"{val}\"" : "Valore di quota \"{val}\" non valido",
    "enabled" : "abilitato",
    "disabled" : "disabilitato",
    "no group" : "nessun gruppo",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Il cambiamento della password causerà una perdita di dati, poiché il ripristino dei dati non è disponibile per questo utente",
    "Password successfully changed" : "Password modificata correttamente",
    "A valid username must be provided" : "Deve essere fornito un nome utente valido",
    "Error creating user: {message}" : "Errore durante la creazione dell'utente: {message}",
    "A valid password must be provided" : "Deve essere fornita una password valida",
    "A valid email must be provided" : "Deve essere fornito un indirizzo email valido",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Ciao,<br><br>volevo informarti che ora hai un account %s.<br><br>Il tuo nome utente: %s<br>Accedi: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Saluti!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ciao,\n\nvolevo informarti che ora hai un account %s.\n\nIl tuo nome utente: %s\nAccedi: %s\n\n",
    "User documentation" : "Documentazione utente",
    "Administrator documentation" : "Documentazione amministratore",
    "Online documentation" : "Documentazione in linea",
    "Forum" : "Forum",
    "Issue tracker" : "Sistema di tracciamento dei problemi",
    "Commercial support" : "Supporto commerciale",
    "Apps Management" : "Gestione applicazioni",
    "Developer documentation" : "Documentazione dello sviluppatore",
    "by %s" : "di %s",
    "%s-licensed" : "sotto licenza %s",
    "Documentation:" : "Documentazione:",
    "Admin documentation" : "Documentazione di amministrazione",
    "Visit website" : "Visita il sito web",
    "Report a bug" : "Segnala un bug",
    "Show description …" : "Mostra descrizione...",
    "Hide description …" : "Nascondi descrizione...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Questa applicazione non ha una versione minima di ownCloud assegnata. Ciò costituirà un errore in ownCloud 11 e successive.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Questa applicazione non ha una versione massima di ownCloud assegnata. Ciò costituirà un errore in ownCloud 11 e successive.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Questa applicazione non può essere installata perché le seguenti dipendenze non sono soddisfatte:",
    "Enable only for specific groups" : "Abilita solo per gruppi specifici",
    "Uninstall App" : "Disinstalla applicazione",
    "Show enabled apps" : "Mostra applicazioni abilitate",
    "Show disabled apps" : "Mostra applicazioni disabilitate",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Ultima esecuzione di cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Ultima esecuzione di cron: %s. Potrebbe esserci un problema.",
    "Cron was not executed yet!" : "Cron non è stato ancora eseguito!",
    "Open documentation" : "Apri la documentazione",
    "Execute one task with each page loaded" : "Esegui un'operazione con ogni pagina caricata",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php è registrato su un servizio webcron per invocare cron.php ogni 15 minuti su http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usa il servizio cron di sistema per invocare il file cron.php ogni 15 minuti.",
    "SSL Root Certificates" : "Certificati radice SSL",
    "Common Name" : "Nome comune",
    "Valid until" : "Valido fino al",
    "Issued By" : "Emesso da",
    "Valid until %s" : "Valido fino al %s",
    "Import root certificate" : "Importa certificato radice",
    "Server-side encryption" : "Cifratura lato server",
    "Enable server-side encryption" : "Abilita cifratura lato server",
    "Please read carefully before activating server-side encryption: " : "Leggi attentamente prima di attivare la cifratura lato server:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Quando la cifratura è abilitata, tutti i file caricati sul server da quel momento in poi saranno cifrati sul server. Sarà possibile solo disabilitare successivamente la cifratura se il modulo di cifratura attivo lo consente, e se tutti i prerequisiti (ad es. l'impostazione di una chiave di recupero) sono verificati.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "La sola cifratura non garantisce la sicurezza del sistema. Vedi la documentazione di ownCloud per ulteriori informazioni su come funziona l'applicazione di cifratura, e per i casi d'uso supportati.",
    "Be aware that encryption always increases the file size." : "Considera che la cifratura incrementa sempre la dimensione dei file.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Ti consigliamo di creare copie di sicurezza dei tuoi dati con regolarità, in caso di utilizzo della cifratura, assicurati di creare una copia delle chiavi di cifratura insieme ai tuoi dati.",
    "This is the final warning: Do you really want to enable encryption?" : "Questo è l'ultimo avviso: vuoi davvero abilitare la cifratura?",
    "Enable encryption" : "Abilita cifratura",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nessun modulo di cifratura caricato, carica un modulo di cifratura nel menu delle applicazioni.",
    "Select default encryption module:" : "Seleziona il modulo di cifratura predefinito:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Devi migrare le tue chiavi di cifratura dalla vecchia cifratura (ownCloud <= 8.0) alla nuova. Abilita il \"Modulo di cifratura predefinito\" ed esegui 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Devi migrare le tue chiavi di cifratura dalla vecchia cifratura (ownCloud <= 8.0) alla nuova.",
    "Start migration" : "Avvia migrazione",
    "Sharing" : "Condivisione",
    "Allow apps to use the Share API" : "Consenti alle applicazioni di utilizzare le API di condivisione",
    "Allow users to share via link" : "Consenti agli utenti di condividere tramite collegamento",
    "Allow public uploads" : "Consenti caricamenti pubblici",
    "Enforce password protection" : "Imponi la protezione con password",
    "Set default expiration date" : "Imposta data di scadenza predefinita",
    "Allow users to send mail notification for shared files" : "Consenti agli utenti di inviare email di notifica per i file condivisi",
    "Allow users to share file via social media" : "Consenti agli utenti di condividere file tramite piattaforme sociali",
    "Expire after " : "Scadenza dopo",
    "days" : "giorni",
    "Enforce expiration date" : "Forza la data di scadenza",
    "Allow resharing" : "Consenti la ri-condivisione",
    "Allow sharing with groups" : "Consentì la condivisione con gruppi",
    "Restrict users to only share with users in their groups" : "Limita gli utenti a condividere solo con gli utenti nei loro gruppi",
    "Allow users to send mail notification for shared files to other users" : "Consenti agli utenti di inviare email di notifica per i file condivisi con altri utenti",
    "Exclude groups from sharing" : "Escludi gruppi dalla condivisione",
    "These groups will still be able to receive shares, but not to initiate them." : "Questi gruppi saranno in grado di ricevere condivisioni, ma non iniziarle.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Consenti il completamento del nome utente nella finestra di condivisione. Se è disabilitata, è necessario digitare il nome utente completo.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tutto (problemi gravi, errori, avvisi, informazioni, debug)",
    "Info, warnings, errors and fatal issues" : "Informazioni, avvisi, errori e problemi gravi",
    "Warnings, errors and fatal issues" : "Avvisi, errori e problemi gravi",
    "Errors and fatal issues" : "Errori e problemi gravi",
    "Fatal issues only" : "Solo problemi gravi",
    "Log" : "Log",
    "What to log" : "Cosa registrare",
    "Download logfile (%s)" : "Scarica file di log (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Il file di log è più grande di 100MB. Scaricarlo potrebbe richiedere del tempo!",
    "None" : "Nessuno",
    "Login" : "Accesso",
    "Plain" : "Semplice",
    "NT LAN Manager" : "Gestore NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Server di posta",
    "This is used for sending out notifications." : "Viene utilizzato per inviare le notifiche.",
    "Send mode" : "Modalità di invio",
    "Encryption" : "Cifratura",
    "From address" : "Indirizzo mittente",
    "mail" : "posta",
    "Authentication method" : "Metodo di autenticazione",
    "Authentication required" : "Autenticazione richiesta",
    "Server address" : "Indirizzo del server",
    "Port" : "Porta",
    "Credentials" : "Credenziali",
    "SMTP Username" : "Nome utente SMTP",
    "SMTP Password" : "Password SMTP",
    "Store credentials" : "Memorizza le credenziali",
    "Test email settings" : "Prova impostazioni email",
    "Send email" : "Invia email",
    "Security & setup warnings" : "Avvisi di sicurezza e di configurazione",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php non sembra essere configurato correttamente per interrogare le variabili d'ambiente di sistema. Il test con getenv(\"PATH\") restituisce solo una risposta vuota.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Controlla la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione di installazione↗</a>  per le note di configurazione di php e la configurazione del tuo server, in particolare quando utilizzi php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configurazione di sola lettura è stata abilitata. Ciò impedisce l'impostazione di alcune configurazioni tramite l'interfaccia web. Inoltre, i file devono essere resi scrivibili manualmente per ogni aggiornamento.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Il tuo database non è in esecuzione con il livello di isolamento delle transazioni \"READ COMMITTED\". Ciò può causare problemi quando diverse azioni sono eseguite in parallelo.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "La versione di %1$s installata è anteriore alla %2$s, per motivi di stabilità e prestazioni, consigliamo di aggiornare a una versione di %1$s più recente.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Il modulo PHP 'fileinfo' non è presente. Consigliamo vivamente di abilitare questo modulo per ottenere risultati migliori con il rilevamento dei tipi MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Il blocco del file transazionale è disabilitato, ciò potrebbe comportare problemi di race condition. Abilita 'filelocking.enabled' nel config-php per evitare questi problemi. Vedi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione ↗</a> per ulteriori informazioni.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Il blocco del file transazionale dovrebbe essere configurato per utilizzare un metodo di blocco basato sulla memoria, non il lento metodo predefinito basato sul database. Vedi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione ↗</a> per ulteriori informazioni.",
    "System locale can not be set to a one which supports UTF-8." : "La localizzazione di sistema non può essere impostata a una che supporta UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Ciò significa che potrebbero esserci problemi con alcuni caratteri nei nomi dei file.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Consigliamo vivamente di installare i pacchetti richiesti sul tuo sistema per supportare una delle localizzazioni seguenti: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se la tua installazione non si trova nella radice del dominio e utilizza il cron di sistema, potrebbero esserci problemi con la generazione degli URL. Per evitare questi problemi, imposta l'opzione \"overwrite.cli.url\"  nel file config.php al percorso della radice del sito della tua installazione (Consigliato: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite è utilizzato come database. Per installazioni più grandi consigliamo di passare a un motore di database diverso.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "In particolar modo, quando si utilizza il client desktop per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Per migrare a un altro database, usa lo strumento da riga di comando: 'occ db:convert-type', o leggi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Consigliamo di abilitare il cron di sistema poiché ogni altro metodo ha potenziali implicazioni sulle prestazioni e sull'affidabilità.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Non è stato possibile eseguire il job di cron tramite CLI. Sono apparsi i seguenti errori tecnici:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Leggi attentamente le  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"#log-section\">log</a>.",
    "All checks passed." : "Tutti i controlli passati.",
    "System Status" : "Stato del sistema",
    "Tips & tricks" : "Suggerimenti e trucchi",
    "How to do backups" : "Come creare delle copie di sicurezza",
    "Advanced monitoring" : "Monitoraggio avanzato",
    "Performance tuning" : "Ottimizzazione delle prestazioni",
    "Improving the config.php" : "Ottimizzare il config.php",
    "Theming" : "Temi",
    "Hardening and security guidance" : "Guida alla messa in sicurezza",
    "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
    "Desktop client" : "Client desktop",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "Show First Run Wizard again" : "Mostra nuovamente la procedura di primo avvio",
    "Profile picture" : "Immagine del profilo",
    "Upload new" : "Carica nuova",
    "Select from Files" : "Seleziona da file",
    "Remove image" : "Rimuovi immagine",
    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
    "Picture provided by original account" : "Immagine fornita dall'account originale",
    "Cancel" : "Annulla",
    "Choose as profile picture" : "Scegli come immagine del profilo",
    "Full name" : "Nome completo",
    "No display name set" : "Nome visualizzato non impostato",
    "Email" : "Posta elettronica",
    "Your email address" : "Il tuo indirizzo email",
    "For password recovery and notifications" : "Per il ripristino della password e per le notifiche",
    "No email address set" : "Nessun indirizzo email impostato",
    "You are member of the following groups:" : "Sei membro dei seguenti gruppi:",
    "Password" : "Password",
    "Unable to change your password" : "Modifica password non riuscita",
    "Current password" : "Password attuale",
    "New password" : "Nuova password",
    "Change password" : "Modifica password",
    "Language" : "Lingua",
    "Help translate" : "Migliora la traduzione",
    "Unlimited" : "Illimitata",
    "You are using %s of %s" : "Stai usando %s di %s",
    "You are using %s of %s (%s %%)" : "Stai usando %s di %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Sviluppato dalla {communityopen}comunità di ownCloud{linkclose}, il {githubopen}codice sorgente{linkclose} è rilasciato nei termini della licenza {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sessioni",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Questi sono i client web, desktop e mobile che hanno effettuato attualmente l'accesso al tuo ownCloud.",
    "Browser" : "Browser",
    "Most recent activity" : "Attività più recenti",
    "App passwords" : "Password di applicazione",
    "You've linked these apps." : "Hai collegato queste applicazioni.",
    "Name" : "Nome",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Una password di applicazione è un codice di sicurezza che fornisce a un'applicazione o a un dispositivo i permessi per accedere al tuo account %s.",
    "App name" : "Nome applicazione",
    "Create new app password" : "Crea nuova password di applicazione",
    "Use the credentials below to configure your app or device." : "Usa le credenziali seguenti per configurare l'applicazione o il dispositivo.",
    "Username" : "Nome utente",
    "Done" : "Completato",
    "Version" : "Versione",
    "Personal" : "Personale",
    "Admin" : "Admin",
    "Error" : "Errore",
    "Show storage location" : "Mostra posizione di archiviazione",
    "Show last log in" : "Mostra ultimo accesso",
    "Show user backend" : "Mostra il motore utente",
    "Send email to new user" : "Invia email al nuovo utente",
    "Show email address" : "Mostra l'indirizzo email",
    "E-Mail" : "Posta elettronica",
    "Create" : "Crea",
    "Admin Recovery Password" : "Password di ripristino amministrativa",
    "Enter the recovery password in order to recover the users files during password change" : "Digita la password di ripristino per recuperare i file degli utenti durante la modifica della password.",
    "Add Group" : "Aggiungi gruppo",
    "Group" : "Gruppo",
    "Everyone" : "Chiunque",
    "Admins" : "Amministratori",
    "Default Quota" : "Quota predefinita",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Digita la quota di archiviazione (ad es.: \"512 MB\" or \"12 GB\")",
    "Other" : "Altro",
    "Full Name" : "Nome completo",
    "Group Admin for" : "Gruppo di amministrazione per",
    "Quota" : "Quote",
    "Storage Location" : "Posizione di archiviazione",
    "User Backend" : "Motore utente",
    "Last Login" : "Ultimo accesso",
    "change full name" : "modica nome completo",
    "set new password" : "imposta una nuova password",
    "change email address" : "cambia l'indirizzo email",
    "Default" : "Predefinito",
    "Change" : "Cambia",
    "Share" : "Condividi",
    "Domain" : "Dominio",
    "Add" : "Aggiungi",
    "Change email" : "Cambia email",
    "Set email" : "Imposta email",
    "Invalid email address" : "Indirizzo email non valido",
    "No panels for this section." : "Nessun pannello per questa sezione.",
    "Email has been changed successfully." : "email cambiata con successo",
    "No Domains." : "Nessun dominio.",
    "Are you sure you want to remove this domain?" : "Sei sicuro di voler rimuovere questo dominio ?",
    "Empty app name is not allowed." : "Nome ssente della app non consentito.",
    "CORS" : "CORS",
    "Failed to change the email address." : "Errore nel cambiare indirizzo email",
    "User ID" : "ID Utente",
    "Email address" : "Indirizzo email",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Il file di configurazione è di sola lettura. Controlla al configurazione editando il file manualmente",
    "Add Domain" : "Aggiungi un dominio",
    "Email changed successfully for {user}." : "Email cambiata con successo per utente {user}.",
    "Restrict enumeration to group members" : "Restringi l'enumerazione ai membri del gruppo",
    "Extra field to display in autocomplete results" : "Campo extra da mostrare in risultati di autocompletamento",
    "White-listed Domains" : "Domini consentiti",
    "You are not a member of any groups." : "Non sei membro di nesssuno dei gruppi",
    "installing and updating apps via the market or Federated Cloud Sharing" : "Installare o aggiornare apps via market o Federated Cloud Sharing",
    "Enforce password protection for read-only links" : "Attivare la protezione con password per link a sola lettura",
    "Enforce password protection for read & write links" : "Attivare la protezione con password per link di lettura e scrittura",
    "Enforce password protection for upload-only (File Drop) links" : "Attivare la protezione con password solo per link di upload (file drop)",
    "Restrict users to only share with groups they are member of" : "Limita gli utenti a condividere solo con gruppi di cui sono membri",
    "Default user and group share permissions" : "Permessi normali per condivisioni utenti e gruppi",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "In una configurazione a cluser, assicurarsi di sincronizzare il file config.php tra tutti i nodi.",
    "You are using %s" : "Sta usando %s",
    "These are the web, desktop and mobile clients currently logged in to your %s." : "Questi sono gli accessi web, da desktop e da mobile connessi attualmente al tuo %s."
},
"nplurals=2; plural=(n != 1);");
